@@ -1,6 +1,6 @@
 cronbach <- function(x) {
 
-  s <- cov(x)
+  s <- Rfast::cova(x)
   p <- dim(s)[1]
   p / (p - 1) * (1 - sum( diag(s) ) / sum(s) )
 
