@@ -9,15 +9,16 @@ cronfree.ci <- function(a, p, n, conf = 0.95, type = "kf"){
 
   } else if ( type == "whalen" ) {
     tau <- (1 - a)^(1/3)
-    up <- 18 * p * (n - 1) (1 - a) ^ ( 2/3 )
+    up <- 18 * p * (n - 1) * (1 - a) ^ ( 2/3 )
     denom <- ( p - 1) * (9 * n - 11)^2
     se <- sqrt( up / denom )
-    ci <- c( tau - za * se, tau + za * se )
+    ci <- c( tau + za * se, tau - za * se )
     ci <- abs(1 - ci^3)
     ci[ci < 0] <- 0    ;   ci[ci > 1] <- 1
   }
 
-  names(ci) <- c( paste( 0.5 * (1 - conf), "%", sep = "" ), paste( conf + 0.5 * (1 - conf), "%", sep = "" ) )
+  names(ci) <- c( paste( 0.5 * (1 - conf), "%", sep = "" ),
+                  paste( conf + 0.5 * (1 - conf), "%", sep = "" ) )
   ci
 
 }
